<?php

/**
 * @file
 * Field hooks for google weather module.
 */

/**
 * Implements hook_field_info().
 */
function google_weather_field_info() {
  return array(
    'google_weather' => array(
      'label' => t("Google weather location"), 
      'description' => t("This field stores and displays google weather data"), 
      'settings' => array('max_length' => 255), 
      'instance_settings' => array('text_processing' => 0), 
      'default_widget' => 'google_weather_location', 
      'default_formatter' => 'google_weather_default',
    ),
  );
}

/**
 * Implements hook_field_schema().
 */
function google_weather_field_schema($field) {
  $columns = array(
    'lid' => array(
      'type' => 'int',
      'default' => NULL,
      'not null' => FALSE,
    ),
  );

  return array(
    'columns' => $columns,
  );
}

/**
 * Implements hook_field_widget_info().
 */
function google_weather_field_widget_info() {
  return array(
    'google_weather_location' => array(
      'label' => t("Google weather location"),
      'field types' => array('google_weather'),
      'settings' => array('size' => 60), 
      'behaviors' => array(
        'multiple values' => FIELD_BEHAVIOR_DEFAULT, 
        'default value' => FIELD_BEHAVIOR_NONE,
      ),
    ),
  );
}

/**
 * Implements hook_field_widget_form().
 */
function google_weather_field_widget_form(&$form, &$form_state, $field, $instance, $langcode, $items, $delta, $element) {
/*
  $element += array(
    
  );
*/
  $element['location'] = array(
    '#title' => check_plain($element['#title']),
    '#type' => 'textfield',
    '#size' => $instance['widget']['settings']['size'],
    '#default_value' => '',
  );
  $element['no_of_days'] = array(
    '#type' => 'select',
    '#options' => _google_weather_days_options(),
    '#default_value' => '',
  );

  $location = isset($items[$delta]['lid']) ? google_weather_location_load($items[$delta]['lid']) : FALSE;

  $element['location'] = array(
    '#title' => check_plain($element['#title']),
    '#type' => 'textfield',
    '#description' => t("Enter your location."),
    '#size' => $instance['widget']['settings']['size'],
    '#default_value' => $location ? $location->location : '',
  );
  $element['no_of_days'] = array(
    '#type' => 'select',
    '#description' => t("Select the amount of days to show on the forecast."),
    '#options' => _google_weather_days_options(),
    '#default_value' => $location ? $location->days : 1,
  );
  $element['lid'] = array(
    '#type' => 'value',
    '#value' => $location ? $location->bid : FALSE,
  );

  return $element;
}

/**
 * Implements_hook_field_presave().
 */
function google_weather_field_presave($entity_type, $entity, $field, $instance, $langcode, &$items) {
  foreach ($items as $delta => $item) {
    if (!google_weather_field_is_empty($item, $field)) {
      // Add field context to all locations saved through field api.
      $item['context'] = 'field';
      $lid = google_weather_location_save((object) $item);
      $items[$delta] = array('lid' => $lid);
    }
  }
}

/**
 * Implements_hook_field_formatter_info().
 */
function google_weather_field_formatter_info() {
  return array(
    'google_weather_default' => array(
      'label' => t("Google weather widget (default)"),
      'field types' => array('google_weather'),
      'settings' => array(
        // None yet.
      ),
    ),
  );
}

/**
 * Implements_hook_field_formatter_settings_form().
 */
function google_weather_field_formatter_settings_form($field, $instance, $view_mode, $form, &$form_state) {
  $display = $instance['display'][$view_mode];
  $settings = $display['settings'];

  $form = array();

  if ($field['type'] == 'text' && $field['module'] == 'text') {
    
  }
}

/**
 * Implements hook_field_is_empty().
 */
function google_weather_field_is_empty($item, $field) {
  if (empty($item['location']) || (strlen($item['location']) <= 0)) {
    return TRUE;
  }
  return FALSE;
}

/**
 * Implements hook_field_formatter_view().
 */
function google_weather_field_formatter_view($entity_type, $entity, $field, $instance, $langcode, $items, $display) {
  global $language;
  $element = array();

  if ($display['type'] == 'google_weather_default') {
    if ($field['type'] == 'google_weather' && $field['module'] == 'google_weather') {
      foreach ($items as $delta => $item) {
        $location = google_weather_location_load($item['lid']);
        if (is_object($location)) {
          $weather = new googleWeather($location, $language);
          $element[$delta] = array(
            '#markup' => google_weather_render($weather->get_weather_data(), 'field'),
          );
        }
      }
    }
  }

  return $element;
}
